Several terms (columns) in DwC format come in pairs of "term" and "termID";
for example, "acceptedNameUsage" and "acceptedNameUsageID", where the first
is the value in a human-readable form (in this case, scientific name of the
accepted taxon) and the second is the value used by a machine (in this case,
taxonID of the accepted taxon). Other pairs include "parentNameUsage" and
"parentNameUsageID", "scientificName" and "scientificNameID", etc. None are
required to be used in a given DwC dataset.
Often when updating data, the user may only fill in one value or the other
(e.g., "acceptedNameUsage" or "acceptedNameUsageID"), but not both. The
purpose of dct_fill_col() is to fill the missing column.
match_from and match_to are used to locate the values used for filling
each cell. The values in the match_to column must be unique.
The default settings are to fill acceptedNameUsage with values from
scientificName by matching acceptedNameUsageID to taxonID (see Example).
When adding timestamps with stamp_modified, any row that differs from the
original data (tax_dat) is considered modified. This includes when a new
column is added, in which case all rows will be considered modified.