powered by
Taxonomic data of filmy ferns (family Hymenophyllaceae) in Darwin Core format. Non-ASCII characters have been converted to ASCII, so some author names may not be as expected. Meant for demonstration purposes only, not formal data analysis.
dct_filmies
Dataframe (tibble), with 2451 rows and 5 columns. For details about data format, see https://dwc.tdwg.org/terms/#taxon.
Modified from data downloaded from the Catalog of Life under the Creative Commons Attribution (CC BY) 4.0 license.
Run the code above in your browser using DataLab